CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * MODULE FEATURES
 * Configuration
 * Maintainers


INTRODUCTION
------------

Provides various optimisations for akamai caching and purge processing.
As per https://learn.akamai.com/en-us/webhelp/fast-purge/fast-purge/GUID-58874706-3157-4BEA-A1C6-6EE02600388D.html there are various limits which
akamai imposes for its edge cache tag header, This main Drupal Akamai module by
default do handle some of these restrictions, and this module provides solution
for the same.

REQUIREMENTS
------------

Purge module. See: https://www.drupal.org/project/purge.
Akamai module. See: https://www.drupal.org/project/akamai
To work correctly, this patch (https://www.drupal.org/project/akamai/issues/3160999#comment-13762094) needs to be applied on akamai module

INSTALLATION
------------

Refer the Purge documentation to get more details on how to setup the various
purge modules and processors.
https://git.drupalcode.org/project/purge/-/blob/8.x-3.x/README.md

Also refer Akamai documentation for configuring Akamai setup.
https://git.drupalcode.org/project/akamai/-/blob/8.x-3.x/README.md

MODULE FEATURES
---------------

* Solves the problem of akamai edge cache tag header limit of 8192 characters
  - This is achieved by created 5 character hashes of each tag.
* Includes the functionality of reducing more than 128 tags on a page.
  - Provides a configuration to define prefixes for the tags which should be
    replaced with an identifier.
  - In edge cache tag header for all the tags which are matching the prefix are
    replaced with an identifier.
  - Sending replacement tags during purge for the tags which have been removed.
  - Replacement identifiers are stored in a custom table. Also various cron jobs
    are added to analyse priority tags and automatically remove old records from
    this table.
* Adds a site identifier tag on all HTML pages which allows for purging the whole site.
  - Also provides a hook to customise this identifier information.
* Adds support for sending a file identifier for purging. This identifier is not
 added on all the file pages.
* Adds a new AkamaiEverythingPurger to support purging whole akamai cache using
 the site identifier and file identifier.
* Adds a feature to disable akamai caching.

CONFIGURATION
-------------

 * Refer documentation of Purge and Akamai module to configure your base setup.

 * Go to /admin/config/akamai/purge-akamai-optimizer-settings to cofigure and see
   various settings.

 * Site identifier tag: This is display only information so that admins can see what is the identifier generated for a site, No default value is provided.
   - This can be customised by implementing hook_akamai_site_identifier_alter

 * File identifier tag: This is display only information so that admins can see what is the file identifier tag which can be used to purge files at akamai. Note: This cache tag needs to be added from Akamai end / using htaccess for each file.
   - This can be customised by implementing hook_akamai_file_identifier_alter

 * Priority tag setup status: This section is an extension of configurable cache tag prefixes setting. Data represented in this section is either calculated dynamically or is stored in state. The goal of this implementation is to reduce the number of replacement records stored in replacement table. Following values are represented:
   - Replacement table state: This reflects as "non-optimal", if number of records in the replacement table is more than the half the number of nodes in the site and optimisation process has not yet executed or expiry_days / 2 (i.e 16 days) time has passed since last execution, otherwise it reflects as "optimal".
   - Priority tags: This is computed only when Replacement table state is non-optimal during cron run, This is generated by running an analysis on current records in replacement table to see which tags are used the most and the tags with highest usage are stored for replacement priority. The number of tags chosen here is computed on the average number of tags stored per row in replacement table. Once these tags are computed they are used first to replace tags with an identifier.
   - Last executed: Reflects time when this optimisation was last executed. If the execution has not happened yet then its value is "Not executed yet".

 * Cache Tag Prefixes: This config contains the cache tag prefixes which are replaced with an identifier, This config is used in determining which cache tags will be replaced, These tags are only replaced with an identifier if the number of cache tags rendering on a page is more than Akamai header limit(i.e 127). The items mentioned here are replaced in order of priority. Default values are as follows (with the reasoning of the setup):
   - block_view: Rare
   - config - change rate should be low after initial setup
   - block_content - seems it will change rarely after initial setup
   - menu_link_content: variable rate of change

 * Expiry time for replacement identifier: Maximum time a replacement identifier record will be stored in a database. Since each identifier will always be unique hence if a page cache tags change than that record will not be valid hence it is important to clean up that data. This value should be set to 2 more days than the default max-age setting, and here currently it is set to 3 days

 * Replace threshold: During invalidation, If number of replacements generated is greater than threshold, then site identifier will be used for purging Akamai.
   - This feature only works when site identifier tag is configured.
   - Defaults to 500.

 * Debug Settings: These are various setting which can be used for debugging purposes
   - Disable hashing of cache tags: If enabled hashing of cache tags will be disabled also all the cache tags will render in Edge-cache-tag header. Please note these headers can easily exceed the server header limits and can make the page un-renderable hence this setting should be used only for debugging purposes. This is disabled by default.
   - Monitor Performance for hashing and tags reduction: Logs the time used for reducing and hashing of tags. Disabled by default.
   - Disable Akamai caching: Disables the Akamai caching for the site by adding edge-control header to the response with a value set to no-cache, no-store

MAINTAINERS
-----------

Current maintainers:
 * Hemant Gupta (https://www.drupal.org/u/guptahemant)
 * Graham Arrowsmith (https://www.drupal.org/u/arrowsmith)
